@@ -1,7 +1,7 @@
 <?php
 /*
  * Copyright 2005 Randy Smith <perlstalker@gmail.com>
- * $Id: hooks.php,v 1.3 2005/10/06 19:41:58 randy Exp $
+ * $Id: hooks.php,v 1.4 2005/10/07 15:31:18 randy Exp $
  */
 
 if (!defined ('SM_PATH')) { define ('SM_PATH','../../'); }
@@ -14,7 +14,18 @@ function ws_menuline () {
   bindtextdomain('web_search', SM_PATH.'locale');
   textdomain('web_search');
 
-  displayInternalLink('plugins/web_search/search.php', _("Web Search"));
+  include(SM_PATH.'plugins/web_search/web_search.conf.php');
+
+  if (isset($search_in_right) && $search_in_right) {
+    include_once (SM_PATH.'plugins/web_search/api.php');
+    echo "<div style='position:absolute;top:10px;right:7em'>";
+    mini_search();
+    echo "</div>";
+  }
+
+  if (isset($advanced_search) && $advanced_search) {
+    //displayInternalLink('plugins/web_search/search.php', _("Web Search"));
+  }
 
   // put it back
   bindtextdomain('squirrelmail', SM_PATH.'locale');
