@@ -3,7 +3,7 @@
 /*
  * web_search - Generic web search box
  * by Randy Smith
- * $Id: setup.php,v 1.7 2005/10/06 19:53:49 randy Exp $
+ * $Id: setup.php,v 1.9 2005/10/07 15:31:46 randy Exp $
  */
 
 if (!defined ('SM_PATH')) { define ('SM_PATH','../../'); }
@@ -15,7 +15,7 @@ function squirrelmail_plugin_init_web_search () {
     return;
   }
 
-  //  $squirrelmail_plugin_hooks['menuline']['web_search'] = 'ws_menuline_stub';
+  $squirrelmail_plugin_hooks['menuline']['web_search'] = 'ws_menuline_stub';
   $squirrelmail_plugin_hooks['left_main_before']['web_search'] = 'ws_left_main_before_stub';
   $squirrelmail_plugin_hooks['left_main_after']['web_search'] = 'ws_left_main_after_stub';
 }
@@ -35,6 +35,6 @@ function ws_left_main_after_stub () {
   ws_left_main_after();
 }
 
-function web_search_version () { return '0.1.5'; }
+function web_search_version () { return '0.1.6'; }
 
 ?>
\ No newline at end of file
